==> haskell-tuple-0.3.0.2-168-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-tuple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tuple
version:              0.3.0.2
visibility:           public
id:                   tuple-0.3.0.2-2oaPd8CmRcuGv30IANfAKx
key:                  tuple-0.3.0.2-2oaPd8CmRcuGv30IANfAKx
license:              BSD-3-Clause
copyright:            2014 Lennart Augustsson
maintainer:           Lennart Augustsson
author:               Lennart Augustsson
stability:            stable
synopsis:             Various functions on tuples
description:
    Various useful functions on tuples, overloaded on tuple size.

category:             Data
abi:                  50a1d1acb6eaa847224ff594e85dfe81
exposed:              True
exposed-modules:
    Data.Tuple.All Data.Tuple.Curry Data.Tuple.Select
    Data.Tuple.Sequence Data.Tuple.Update

import-dirs:          /usr/lib/ghc-9.6.6/site-local/tuple-0.3.0.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/tuple-0.3.0.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/tuple-0.3.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tuple
hs-libraries:         HStuple-0.3.0.2-2oaPd8CmRcuGv30IANfAKx
depends:              OneTuple-0.4.2-6pEN3mXYu4CEsP59PDdiWd base-4.18.2.1
haddock-interfaces:   /usr/share/doc/haskell-tuple/html/tuple.haddock
haddock-html:         /usr/share/doc/haskell-tuple/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tuple-0.3.0.2-169-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-tuple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tuple
version:              0.3.0.2
visibility:           public
id:                   tuple-0.3.0.2-ALR7ovwJbxyCHAparskNtD
key:                  tuple-0.3.0.2-ALR7ovwJbxyCHAparskNtD
license:              BSD-3-Clause
copyright:            2014 Lennart Augustsson
maintainer:           Lennart Augustsson
author:               Lennart Augustsson
stability:            stable
synopsis:             Various functions on tuples
description:
    Various useful functions on tuples, overloaded on tuple size.

category:             Data
abi:                  4ddc91177932636a615c6abca1137e4a
exposed:              True
exposed-modules:
    Data.Tuple.All Data.Tuple.Curry Data.Tuple.Select
    Data.Tuple.Sequence Data.Tuple.Update

import-dirs:          /usr/lib/ghc-9.6.6/site-local/tuple-0.3.0.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/tuple-0.3.0.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/tuple-0.3.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tuple
hs-libraries:         HStuple-0.3.0.2-ALR7ovwJbxyCHAparskNtD
depends:              OneTuple-0.4.2-5DvFAmfc9NS1ZbcfxQYIyW base-4.18.2.1
haddock-interfaces:   /usr/share/doc/haskell-tuple/html/tuple.haddock
haddock-html:         /usr/share/doc/haskell-tuple/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
